//
//  AppController.m
//  CattailArtNSColorDemo
//
//  Created by Theresa Ford on 10/19/08.
//  Copyright 2008 Theresa L. Ford. All rights reserved.  Visit http://www.cattail.nu
//

#import "AppController.h"
#import "CattailArtNSColor.h"


@implementation AppController

@synthesize hueShift;
@synthesize valueShift;
@synthesize saturationShift;
@synthesize alignment;

-(unsigned int)integerFromHex:(NSString *) hexString
{
   unsigned int intValue = 0;
   NSScanner *scanner = [NSScanner scannerWithString:hexString];
   [scanner scanHexInt:&intValue];
   return intValue;
}

-(void)updateColors
{
	CGFloat hue, saturation, brightness, hsbAlpha, red, green, blue, rgbAlpha;

   int loopIndex;
	[[rootColorColorWell color] getHue:&hue saturation:&saturation brightness:&brightness alpha:&hsbAlpha];

	NSLog(@"rootColor : h s b a : %f %f %f %f : r g b a : %f %f %f %f", hue, saturation, brightness, hsbAlpha, red, green, blue, rgbAlpha);

   NSColor *rootColor = [rootColorColorWell color];

   NSColor *colorComplement;
   NSArray *splitComplementArray;
   NSArray *triadArray;
   NSArray *tetradicArray;
   NSArray *analogousArray;
   NSArray *valueArray;
   NSArray *saturationArray;
   NSArray *chromaticArray;
   NSArray *flameArray;

#pragma mark ARRAY_DEFINITIONS

   if ([displayCalculationMatrix selectedTag] == 0) { // NEWTON
      colorComplement = [CattailArtNSColor NewtonComplement:rootColor];
      splitComplementArray = [CattailArtNSColor NewtonSplitComplementArray:rootColor];
      triadArray = [CattailArtNSColor NewtonTriadArray:rootColor];
      tetradicArray = [CattailArtNSColor NewtonTetradicArray:rootColor 
         tetradicDegreesCGFloat:hueShift];
      analogousArray = [CattailArtNSColor NewtonAnalogousArray:rootColor 
         numberOfColorsInt:7 
         stepDegreesCGFloat:hueShift];
      chromaticArray = [CattailArtNSColor NewtonChromaticArray:rootColor 
         numberOfColorsInt:6];
      flameArray = [CattailArtNSColor NewtonFlameArray:rootColor 
         numberOfColorsInt:7 
         hueStepDegreesCGFloat: hueShift
         saturationStepDegreesCGFloat: saturationShift
         brightnessStepDegreesCGFloat: valueShift 
         alignmentInt:alignment];
   }
   else { // RGB
      colorComplement = [CattailArtNSColor RGBComplement:rootColor];
      splitComplementArray = [CattailArtNSColor RGBSplitComplementArray:rootColor];
      triadArray = [CattailArtNSColor RGBTriadArray:rootColor];
      tetradicArray = [CattailArtNSColor RGBTetradicArray:rootColor 
         tetradicDegreesCGFloat:hueShift];
      analogousArray = [CattailArtNSColor RGBAnalogousArray:rootColor 
         numberOfColorsInt:7 
         stepDegreesCGFloat:hueShift];
      chromaticArray = [CattailArtNSColor RGBChromaticArray:rootColor 
         numberOfColorsInt:6];
      flameArray = [CattailArtNSColor RGBFlameArray:rootColor 
         numberOfColorsInt:7 
         hueStepDegreesCGFloat: hueShift
         saturationStepDegreesCGFloat: saturationShift
         brightnessStepDegreesCGFloat: valueShift 
         alignmentInt:alignment];
   }

   valueArray = [CattailArtNSColor ValueArray:rootColor
      numberOfColorsInt:7
      stepDegreesCGFloat:valueShift];

   saturationArray = [CattailArtNSColor SaturationArray:rootColor 
      numberOfColorsInt:7 
      stepDegreesCGFloat:saturationShift];

	if ([displayFormatMatrix selectedTag] == 0) { // HEX / RGB

      [rootColor getRed:&red green:&green blue:&blue alpha:&rgbAlpha];

      [[[complementMatrix cells] objectAtIndex:0] setStringValue:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (red*255.0),(int) (green*255.0),(int) (blue*255.0)] uppercaseString]];
      [[[complementMatrix cells] objectAtIndex:0] setBackgroundColor:rootColor];

      [colorComplement getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
      [[[complementMatrix cells] objectAtIndex:1] setStringValue:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (red*255.0),(int) (green*255.0),(int) (blue*255.0)] uppercaseString]];
      [[[complementMatrix cells] objectAtIndex:1] setBackgroundColor:colorComplement];

      for (loopIndex=0; loopIndex < [splitComplementArray count]; loopIndex++) {
         [[splitComplementArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         [[[splitComplementMatrix cells] objectAtIndex:loopIndex] setStringValue:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (red*255.0),(int) (green*255.0),(int) (blue*255.0)] uppercaseString]];
         [[[splitComplementMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[splitComplementArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [triadArray count]; loopIndex++) {
         [[triadArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         [[[triadMatrix cells] objectAtIndex:loopIndex] setStringValue:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (red*255.0),(int) (green*255.0),(int) (blue*255.0)] uppercaseString]];
         [[[triadMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[triadArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [tetradicArray count]; loopIndex++) {
         [[tetradicArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         [[[tetradicMatrix cells] objectAtIndex:loopIndex] setStringValue:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (red*255.0),(int) (green*255.0),(int) (blue*255.0)] uppercaseString]];
         [[[tetradicMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[tetradicArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [analogousArray count]; loopIndex++) {
         [[analogousArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         [[[analogousMatrix cells] objectAtIndex:loopIndex] setStringValue:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (red*255.0),(int) (green*255.0),(int) (blue*255.0)] uppercaseString]];
         [[[analogousMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[analogousArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [valueArray count]; loopIndex++) {
         [[valueArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         [[[valueMatrix cells] objectAtIndex:loopIndex] setStringValue:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (red*255.0),(int) (green*255.0),(int) (blue*255.0)] uppercaseString]];
         [[[valueMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[valueArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [saturationArray count]; loopIndex++) {
         [[saturationArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         [[[saturationMatrix cells] objectAtIndex:loopIndex] setStringValue:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (red*255.0),(int) (green*255.0),(int) (blue*255.0)] uppercaseString]];
         [[[saturationMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[saturationArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [chromaticArray count]; loopIndex++) {
         [[chromaticArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         [[[chromaticMatrix cells] objectAtIndex:loopIndex] setStringValue:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (red*255.0),(int) (green*255.0),(int) (blue*255.0)] uppercaseString]];
         [[[chromaticMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[chromaticArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [flameArray count]; loopIndex++) {
         [[flameArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         [[[flameMatrix cells] objectAtIndex:loopIndex] setStringValue:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (red*255.0),(int) (green*255.0),(int) (blue*255.0)] uppercaseString]];
         [[[flameMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[flameArray objectAtIndex:loopIndex]];
      }
   }
	else if ([displayFormatMatrix selectedTag] == 1) { // HSB / HSV

      [[[complementMatrix cells] objectAtIndex:0] setStringValue:[[NSString stringWithFormat:@"%d %d %d",(int) (hue*360.0),(int) (saturation*100.0),(int) (brightness*100.0)] uppercaseString]];
      [[[complementMatrix cells] objectAtIndex:0] setBackgroundColor:rootColor];

      [colorComplement getHue:&hue saturation:&saturation brightness:&brightness alpha:&hsbAlpha];
      [[[complementMatrix cells] objectAtIndex:1] setStringValue:[[NSString stringWithFormat:@"%d %d %d",(int) (hue*360.0),(int) (saturation*100.0),(int) (brightness*100.0)] uppercaseString]];
      [[[complementMatrix cells] objectAtIndex:1] setBackgroundColor:colorComplement];

      for (loopIndex=0; loopIndex < [splitComplementArray count]; loopIndex++) {
         [[splitComplementArray objectAtIndex:loopIndex] getHue:&hue saturation:&saturation brightness:&brightness alpha:&hsbAlpha];
         [[[splitComplementMatrix cells] objectAtIndex:loopIndex] setStringValue:[[NSString stringWithFormat:@"%d %d %d",(int) (hue*360.0),(int) (saturation*100.0),(int) (brightness*100.0)] uppercaseString]];
         [[[splitComplementMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[splitComplementArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [triadArray count]; loopIndex++) {
         [[triadArray objectAtIndex:loopIndex] getHue:&hue saturation:&saturation brightness:&brightness alpha:&hsbAlpha];
         [[[triadMatrix cells] objectAtIndex:loopIndex] setStringValue:[[NSString stringWithFormat:@"%d %d %d",(int) (hue*360.0),(int) (saturation*100.0),(int) (brightness*100.0)] uppercaseString]];
         [[[triadMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[triadArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [tetradicArray count]; loopIndex++) {
         [[tetradicArray objectAtIndex:loopIndex] getHue:&hue saturation:&saturation brightness:&brightness alpha:&hsbAlpha];
         [[[tetradicMatrix cells] objectAtIndex:loopIndex] setStringValue:[[NSString stringWithFormat:@"%d %d %d",(int) (hue*360.0),(int) (saturation*100.0),(int) (brightness*100.0)] uppercaseString]];
         [[[tetradicMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[tetradicArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [analogousArray count]; loopIndex++) {
         [[analogousArray objectAtIndex:loopIndex] getHue:&hue saturation:&saturation brightness:&brightness alpha:&hsbAlpha];
         [[[analogousMatrix cells] objectAtIndex:loopIndex] setStringValue:[[NSString stringWithFormat:@"%d %d %d",(int) (hue*360.0),(int) (saturation*100.0),(int) (brightness*100.0)] uppercaseString]];
         [[[analogousMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[analogousArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [valueArray count]; loopIndex++) {
         [[valueArray objectAtIndex:loopIndex] getHue:&hue saturation:&saturation brightness:&brightness alpha:&hsbAlpha];
         [[[valueMatrix cells] objectAtIndex:loopIndex] setStringValue:[[NSString stringWithFormat:@"%d %d %d",(int) (hue*360.0),(int) (saturation*100.0),(int) (brightness*100.0)] uppercaseString]];
         [[[valueMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[valueArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [saturationArray count]; loopIndex++) {
         [[saturationArray objectAtIndex:loopIndex] getHue:&hue saturation:&saturation brightness:&brightness alpha:&hsbAlpha];
         [[[saturationMatrix cells] objectAtIndex:loopIndex] setStringValue:[[NSString stringWithFormat:@"%d %d %d",(int) (hue*360.0),(int) (saturation*100.0),(int) (brightness*100.0)] uppercaseString]];
         [[[saturationMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[saturationArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [chromaticArray count]; loopIndex++) {
         [[chromaticArray objectAtIndex:loopIndex] getHue:&hue saturation:&saturation brightness:&brightness alpha:&hsbAlpha];
         [[[chromaticMatrix cells] objectAtIndex:loopIndex] setStringValue:[[NSString stringWithFormat:@"%d %d %d",(int) (hue*360.0),(int) (saturation*100.0),(int) (brightness*100.0)] uppercaseString]];
         [[[chromaticMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[chromaticArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [flameArray count]; loopIndex++) {
         [[flameArray objectAtIndex:loopIndex] getHue:&hue saturation:&saturation brightness:&brightness alpha:&hsbAlpha];
         [[[flameMatrix cells] objectAtIndex:loopIndex] setStringValue:[[NSString stringWithFormat:@"%d %d %d",(int) (hue*360.0),(int) (saturation*100.0),(int) (brightness*100.0)] uppercaseString]];
         [[[flameMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[flameArray objectAtIndex:loopIndex]];
      }
   }
	else if ([displayFormatMatrix selectedTag] == 2) { // Decimal

      unsigned int intValue;

      [rootColor getRed:&red green:&green blue:&blue alpha:&rgbAlpha];

      intValue = [self integerFromHex:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (blue*255.0),(int) (green*255.0),(int) (red*255.0)] uppercaseString]];
      [[[complementMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"%d",intValue]];
      [[[complementMatrix cells] objectAtIndex:0] setBackgroundColor:rootColor];

      [colorComplement getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
      intValue = [self integerFromHex:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (blue*255.0),(int) (green*255.0),(int) (red*255.0)] uppercaseString]];
      [[[complementMatrix cells] objectAtIndex:1] setStringValue:[NSString stringWithFormat:@"%d",intValue]];
      [[[complementMatrix cells] objectAtIndex:1] setBackgroundColor:colorComplement];

      for (loopIndex=0; loopIndex < [splitComplementArray count]; loopIndex++) {
         [[splitComplementArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         intValue = [self integerFromHex:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (blue*255.0),(int) (green*255.0),(int) (red*255.0)] uppercaseString]];
         [[[splitComplementMatrix cells] objectAtIndex:loopIndex] setStringValue:[NSString stringWithFormat:@"%d",intValue]];
         [[[splitComplementMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[splitComplementArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [triadArray count]; loopIndex++) {
         [[triadArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         intValue = [self integerFromHex:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (blue*255.0),(int) (green*255.0),(int) (red*255.0)] uppercaseString]];
         [[[triadMatrix cells] objectAtIndex:loopIndex] setStringValue:[NSString stringWithFormat:@"%d",intValue]];
         [[[triadMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[triadArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [tetradicArray count]; loopIndex++) {
         [[tetradicArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         intValue = [self integerFromHex:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (blue*255.0),(int) (green*255.0),(int) (red*255.0)] uppercaseString]];
         [[[tetradicMatrix cells] objectAtIndex:loopIndex] setStringValue:[NSString stringWithFormat:@"%d",intValue]];
         [[[tetradicMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[tetradicArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [analogousArray count]; loopIndex++) {
         [[analogousArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         intValue = [self integerFromHex:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (blue*255.0),(int) (green*255.0),(int) (red*255.0)] uppercaseString]];
         [[[analogousMatrix cells] objectAtIndex:loopIndex] setStringValue:[NSString stringWithFormat:@"%d",intValue]];
         [[[analogousMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[analogousArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [valueArray count]; loopIndex++) {
         [[valueArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         intValue = [self integerFromHex:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (blue*255.0),(int) (green*255.0),(int) (red*255.0)] uppercaseString]];
         [[[valueMatrix cells] objectAtIndex:loopIndex] setStringValue:[NSString stringWithFormat:@"%d",intValue]];
         [[[valueMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[valueArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [saturationArray count]; loopIndex++) {
         [[saturationArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         intValue = [self integerFromHex:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (blue*255.0),(int) (green*255.0),(int) (red*255.0)] uppercaseString]];
         [[[saturationMatrix cells] objectAtIndex:loopIndex] setStringValue:[NSString stringWithFormat:@"%d",intValue]];
         [[[saturationMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[saturationArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [chromaticArray count]; loopIndex++) {
         [[chromaticArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         intValue = [self integerFromHex:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (blue*255.0),(int) (green*255.0),(int) (red*255.0)] uppercaseString]];
         [[[chromaticMatrix cells] objectAtIndex:loopIndex] setStringValue:[NSString stringWithFormat:@"%d",intValue]];
         [[[chromaticMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[chromaticArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [flameArray count]; loopIndex++) {
         [[flameArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         intValue = [self integerFromHex:[[NSString stringWithFormat:@"%02x%02x%02x",(int) (blue*255.0),(int) (green*255.0),(int) (red*255.0)] uppercaseString]];
         [[[flameMatrix cells] objectAtIndex:loopIndex] setStringValue:[NSString stringWithFormat:@"%d",intValue]];
         [[[flameMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[flameArray objectAtIndex:loopIndex]];
      }
   }
	else if ([displayFormatMatrix selectedTag] == 3) { // NSColor

      [rootColor getRed:&red green:&green blue:&blue alpha:&rgbAlpha];

       //	NSColor *rootColorBlue = [NSColor colorWithCalibratedRed:0.0 green:0.5 blue:1.0 alpha:1.0];

      [[[complementMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"NSColor *color0 = [NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0];", red, green, blue]];
      [[[complementMatrix cells] objectAtIndex:0] setBackgroundColor:rootColor];

      [colorComplement getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
      [[[complementMatrix cells] objectAtIndex:1] setStringValue:[NSString stringWithFormat:@"NSColor *color1 = [NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0];", red, green, blue]];
      [[[complementMatrix cells] objectAtIndex:1] setBackgroundColor:colorComplement];

      for (loopIndex=0; loopIndex < [splitComplementArray count]; loopIndex++) {
         [[splitComplementArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         [[[splitComplementMatrix cells] objectAtIndex:loopIndex] setStringValue:[NSString stringWithFormat:@"NSColor *color%d = [NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0];", loopIndex, red, green, blue]];
         [[[splitComplementMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[splitComplementArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [triadArray count]; loopIndex++) {
         [[triadArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         [[[triadMatrix cells] objectAtIndex:loopIndex] setStringValue:[NSString stringWithFormat:@"NSColor *color%d = [NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0];", loopIndex, red, green, blue]];
         [[[triadMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[triadArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [tetradicArray count]; loopIndex++) {
         [[tetradicArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         [[[tetradicMatrix cells] objectAtIndex:loopIndex] setStringValue:[NSString stringWithFormat:@"NSColor *color%d = [NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0];", loopIndex, red, green, blue]];
         [[[tetradicMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[tetradicArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [analogousArray count]; loopIndex++) {
         [[analogousArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         [[[analogousMatrix cells] objectAtIndex:loopIndex] setStringValue:[NSString stringWithFormat:@"NSColor *color%d = [NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0];", loopIndex, red, green, blue]];
         [[[analogousMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[analogousArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [valueArray count]; loopIndex++) {
         [[valueArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         [[[valueMatrix cells] objectAtIndex:loopIndex] setStringValue:[NSString stringWithFormat:@"NSColor *color%d = [NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0];", loopIndex, red, green, blue]];
         [[[valueMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[valueArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [saturationArray count]; loopIndex++) {
         [[saturationArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         [[[saturationMatrix cells] objectAtIndex:loopIndex] setStringValue:[NSString stringWithFormat:@"NSColor *color%d = [NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0];", loopIndex, red, green, blue]];
         [[[saturationMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[saturationArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [chromaticArray count]; loopIndex++) {
         [[chromaticArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         [[[chromaticMatrix cells] objectAtIndex:loopIndex] setStringValue:[NSString stringWithFormat:@"NSColor *color%d = [NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0];", loopIndex, red, green, blue]];
         [[[chromaticMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[chromaticArray objectAtIndex:loopIndex]];
      }

      for (loopIndex=0; loopIndex < [flameArray count]; loopIndex++) {
         [[flameArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         [[[flameMatrix cells] objectAtIndex:loopIndex] setStringValue:[NSString stringWithFormat:@"NSColor *color%d = [NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0];", loopIndex, red, green, blue]];
         [[[flameMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[flameArray objectAtIndex:loopIndex]];
      }
   }
	else if ([displayFormatMatrix selectedTag] == 4) { // NSArray

      NSString *startString;
      NSString *midString;
      NSString *endString;

      /* building:

            NSArray *complementsArray = [NSArray arrayWithObjects:
               [NSColor colorWithCalibratedRed:0.3 green:0.3 blue:0.2 alpha:1],
               [NSColor colorWithCalibratedRed:0.5 green:0.5 blue:0.5 alpha:1],
               nil];
      */
      
      startString = @"NSArray *colorsArray = [NSArray arrayWithObjects:\n";
      endString = @"\tnil];";
      midString = @"";

      [rootColor getRed:&red green:&green blue:&blue alpha:&rgbAlpha];

       //	NSColor *rootColorBlue = [NSColor colorWithCalibratedRed:0.0 green:0.5 blue:1.0 alpha:1.0];

      midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
      [[[complementMatrix cells] objectAtIndex:0] setBackgroundColor:rootColor];

      [colorComplement getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
      midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
      [[[complementMatrix cells] objectAtIndex:1] setBackgroundColor:colorComplement];
      [[[complementMatrix cells] objectAtIndex:1] setStringValue:@""];

      [[[complementMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"%@%@%@", startString, midString, endString]];

      midString = @"";
      for (loopIndex=0; loopIndex < [splitComplementArray count]; loopIndex++) {
         [[splitComplementArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
         [[[splitComplementMatrix cells] objectAtIndex:loopIndex] setStringValue:@""];
         [[[splitComplementMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[splitComplementArray objectAtIndex:loopIndex]];
      }
      [[[splitComplementMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"%@%@%@", startString, midString, endString]];

      midString = @"";
      for (loopIndex=0; loopIndex < [triadArray count]; loopIndex++) {
         [[triadArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
         [[[triadMatrix cells] objectAtIndex:loopIndex] setStringValue:@""];
         [[[triadMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[triadArray objectAtIndex:loopIndex]];
      }
      [[[triadMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"%@%@%@", startString, midString, endString]];

      midString = @"";
      for (loopIndex=0; loopIndex < [tetradicArray count]; loopIndex++) {
         [[tetradicArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
         [[[tetradicMatrix cells] objectAtIndex:loopIndex] setStringValue:@""];
         [[[tetradicMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[tetradicArray objectAtIndex:loopIndex]];
      }
      [[[tetradicMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"%@%@%@", startString, midString, endString]];

      midString = @"";
      for (loopIndex=0; loopIndex < [analogousArray count]; loopIndex++) {
         [[analogousArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
         [[[analogousMatrix cells] objectAtIndex:loopIndex] setStringValue:@""];
         [[[analogousMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[analogousArray objectAtIndex:loopIndex]];
      }
      [[[analogousMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"%@%@%@", startString, midString, endString]];

      midString = @"";
      for (loopIndex=0; loopIndex < [valueArray count]; loopIndex++) {
         [[valueArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
         [[[valueMatrix cells] objectAtIndex:loopIndex] setStringValue:@""];
         [[[valueMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[valueArray objectAtIndex:loopIndex]];
      }
      [[[valueMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"%@%@%@", startString, midString, endString]];

      midString = @"";
      for (loopIndex=0; loopIndex < [saturationArray count]; loopIndex++) {
         [[saturationArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
         [[[saturationMatrix cells] objectAtIndex:loopIndex] setStringValue:@""];
         [[[saturationMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[saturationArray objectAtIndex:loopIndex]];
      }
      [[[saturationMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"%@%@%@", startString, midString, endString]];

      midString = @"";
      for (loopIndex=0; loopIndex < [chromaticArray count]; loopIndex++) {
         [[chromaticArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
         [[[chromaticMatrix cells] objectAtIndex:loopIndex] setStringValue:@""];
         [[[chromaticMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[chromaticArray objectAtIndex:loopIndex]];
      }
      [[[chromaticMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"%@%@%@", startString, midString, endString]];

      midString = @"";
      for (loopIndex=0; loopIndex < [flameArray count]; loopIndex++) {
         [[flameArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
         [[[flameMatrix cells] objectAtIndex:loopIndex] setStringValue:@""];
         [[[flameMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[flameArray objectAtIndex:loopIndex]];
      }
      [[[flameMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"%@%@%@", startString, midString, endString]];
   }
	else if ([displayFormatMatrix selectedTag] == 5) { // NSView drawRect

      NSString *startString;
      NSString *midString;
      NSString *midString2;
      NSString *midString3;
      NSString *endString;
      NSString *newtonRGBString;

      if ([displayCalculationMatrix selectedTag] == 0) // NEWTON
         newtonRGBString = @"Newton";
      else
         newtonRGBString = @"RGB";

      /* building:

      // NSView subclass code

      - (void)drawRect:(NSRect)rect {
         // Drawing code here.
         NSArray *colorsArray = [NSArray arrayWithObjects:
            [NSColor colorWithCalibratedRed:0.3 green:0.3 blue:0.2 alpha:1],
            [NSColor colorWithCalibratedRed:0.5 green:0.5 blue:0.5 alpha:1],
            nil];
         NSGradient *gradient = [[NSGradient alloc] initWithColors:colorsArray];
         [gradient drawInRect:[self bounds] angle:270];
      }

      // Using CattailArtNSColor which is useful for dynamic color changes or gradient tweaking.

      #import "CattailArtNSColor.h"

      - (void)drawRect:(NSRect)rect {
         // Drawing code here.
         NSColor *rootColor = [NSColor colorWithCalibratedRed:0.3 green:0.3 blue:0.2 alpha:1];
         NSArray  *colorsArray = [CattailArtNSColor NewtonFlameArray:rootColor 
            numberOfColorsInt:3 
            hueStepDegreesCGFloat: 60.0
            saturationStepDegreesCGFloat: 0.0
            brightnessStepDegreesCGFloat:15.0 
            alignmentInt:1];
         NSGradient *gradient = [[NSGradient alloc] initWithColors:colorsArray];
         [gradient drawInRect:[self bounds] angle:270];
      }

      */
      
      startString = @"// NSView subclass code\n\n- (void)drawRect:(NSRect)rect {\n\t// Drawing code here.\n\tNSArray *colorsArray = [NSArray arrayWithObjects:\n";
      midString = @""; // static colors as in the above option.
      [rootColor getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
      midString2 = [NSString stringWithFormat:@"\tnil];\n\tNSGradient *gradient = [[NSGradient alloc] initWithColors:colorsArray];\n\t[gradient drawInRect:[self bounds] angle:270];\n}\n\n// Using CattailArtNSColor which is useful for dynamic color changes or gradient tweaking.\n\n#import \"CattailArtNSColor.h\"\n\n- (void)drawRect:(NSRect)rect {\n\t// Drawing code here.\n\tNSColor *rootColor = [NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0];\n", red, green, blue];
      midString3 = @""; // Array for CattailArtNSColor
      endString = @"\tNSGradient *gradient = [[NSGradient alloc] initWithColors:colorsArray];\n\t[gradient drawInRect:[self bounds] angle:270];\n}";


       //	NSColor *rootColorBlue = [NSColor colorWithCalibratedRed:0.0 green:0.5 blue:1.0 alpha:1.0];

      midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
      [[[complementMatrix cells] objectAtIndex:0] setBackgroundColor:rootColor];

      [colorComplement getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
      midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
      [[[complementMatrix cells] objectAtIndex:1] setBackgroundColor:colorComplement];
      [[[complementMatrix cells] objectAtIndex:1] setStringValue:@""];
      // complement is different than the others, silly coder should have made them the same.
      /*
         NSArray *colorsArray = [NSArray arrayWithObjects:
            rootColor,
            [CattailArtNSColor NewtonComplement:rootColor],
            nil];
      */

      midString3 = [NSString stringWithFormat:@"\tNSArray *colorsArray = [NSArray arrayWithObjects:\n\t\trootColor,\n\t\t[CattailArtNSColor %@Complement:rootColor],\n\t\tnil];\n", newtonRGBString];

      [[[complementMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"%@%@%@%@%@", startString, midString, midString2, midString3, endString]];

      midString = @"";
      for (loopIndex=0; loopIndex < [splitComplementArray count]; loopIndex++) {
         [[splitComplementArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
         [[[splitComplementMatrix cells] objectAtIndex:loopIndex] setStringValue:@""];
         [[[splitComplementMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[splitComplementArray objectAtIndex:loopIndex]];
      }
      midString3 = [NSString stringWithFormat:@"\tNSArray *colorsArray = [CattailArtNSColor %@SplitComplementArray:rootColor];\n", newtonRGBString];
      [[[splitComplementMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"%@%@%@%@%@", startString, midString, midString2, midString3, endString]];

      midString = @"";
      for (loopIndex=0; loopIndex < [triadArray count]; loopIndex++) {
         [[triadArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
         [[[triadMatrix cells] objectAtIndex:loopIndex] setStringValue:@""];
         [[[triadMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[triadArray objectAtIndex:loopIndex]];
      }
      midString3 = [NSString stringWithFormat:@"\tNSArray *colorsArray = [CattailArtNSColor %@TriadArray:rootColor];\n", newtonRGBString];
      [[[triadMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"%@%@%@%@%@", startString, midString, midString2, midString3, endString]];

      midString = @"";
      for (loopIndex=0; loopIndex < [tetradicArray count]; loopIndex++) {
         [[tetradicArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
         [[[tetradicMatrix cells] objectAtIndex:loopIndex] setStringValue:@""];
         [[[tetradicMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[tetradicArray objectAtIndex:loopIndex]];
      }
      midString3 = [NSString stringWithFormat:@"\tNSArray *colorsArray = [CattailArtNSColor %@TetradicArray:rootColor\t\ttetradicDegreesCGFloat:%1.2f];\n", newtonRGBString, hueShift];
      [[[tetradicMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"%@%@%@%@%@", startString, midString, midString2, midString3, endString]];

      midString = @"";
      for (loopIndex=0; loopIndex < [analogousArray count]; loopIndex++) {
         [[analogousArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
         [[[analogousMatrix cells] objectAtIndex:loopIndex] setStringValue:@""];
         [[[analogousMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[analogousArray objectAtIndex:loopIndex]];
      }
      midString3 = [NSString stringWithFormat:@"\tNSArray *colorsArray = [CattailArtNSColor %@AnalogousArray:rootColor\t\tnumberOfColorsInt:7\n\t\tstepDegreesCGFloat:%1.2f];\n", newtonRGBString, hueShift];
      [[[analogousMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"%@%@%@%@%@", startString, midString, midString2, midString3, endString]];

      midString = @"";
      for (loopIndex=0; loopIndex < [valueArray count]; loopIndex++) {
         [[valueArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
         [[[valueMatrix cells] objectAtIndex:loopIndex] setStringValue:@""];
         [[[valueMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[valueArray objectAtIndex:loopIndex]];
      }
      midString3 = [NSString stringWithFormat:@"\tNSArray *colorsArray = [CattailArtNSColor ValueArray:rootColor\t\tnumberOfColorsInt:7\n\t\tstepDegreesCGFloat:%1.2f];\n", valueShift];
      [[[valueMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"%@%@%@%@%@", startString, midString, midString2, midString3, endString]];

      midString = @"";
      for (loopIndex=0; loopIndex < [saturationArray count]; loopIndex++) {
         [[saturationArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
         [[[saturationMatrix cells] objectAtIndex:loopIndex] setStringValue:@""];
         [[[saturationMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[saturationArray objectAtIndex:loopIndex]];
      }
      midString3 = [NSString stringWithFormat:@"\tNSArray *colorsArray = [CattailArtNSColor SaturationArray:rootColor\t\tnumberOfColorsInt:7\n\t\tstepDegreesCGFloat:%1.2f];\n", saturationShift];
      [[[saturationMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"%@%@%@%@%@", startString, midString, midString2, midString3, endString]];

      midString = @"";
      for (loopIndex=0; loopIndex < [chromaticArray count]; loopIndex++) {
         [[chromaticArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
         [[[chromaticMatrix cells] objectAtIndex:loopIndex] setStringValue:@""];
         [[[chromaticMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[chromaticArray objectAtIndex:loopIndex]];
      }
      midString3 = [NSString stringWithFormat:@"\tNSArray *colorsArray = [CattailArtNSColor %@ChromaticArray:rootColor\t\tnumberOfColorsInt:6];\n", newtonRGBString];
      [[[chromaticMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"%@%@%@%@%@", startString, midString, midString2, midString3, endString]];

      midString = @"";
      for (loopIndex=0; loopIndex < [flameArray count]; loopIndex++) {
         [[flameArray objectAtIndex:loopIndex] getRed:&red green:&green blue:&blue alpha:&rgbAlpha];
         midString = [midString stringByAppendingString:[NSString stringWithFormat:@"\t[NSColor colorWithCalibratedRed:%1.2f green:%1.2f blue:%1.2f alpha:1.0],\n", red, green, blue]];
         [[[flameMatrix cells] objectAtIndex:loopIndex] setStringValue:@""];
         [[[flameMatrix cells] objectAtIndex:loopIndex] setBackgroundColor:[flameArray objectAtIndex:loopIndex]];
      }
      midString3 = [NSString stringWithFormat:@"\tNSArray *colorsArray = [CattailArtNSColor %@FlameArray:rootColor\n\t\tnumberOfColorsInt:7\n\t\thueStepDegreesCGFloat:%1.2f\n\t\tsaturationStepDegreesCGFloat:%1.2f\n\t\tbrightnessStepDegreesCGFloat:%1.2f\n\t\talignmentInt:%d];\n", newtonRGBString, hueShift, saturationShift, valueShift, alignment];
      [[[flameMatrix cells] objectAtIndex:0] setStringValue:[NSString stringWithFormat:@"%@%@%@%@%@", startString, midString, midString2, midString3, endString]];
   }
}

#pragma mark INITIALIZE

- (void)awakeFromNib
{
	NSColor *rootColorBlue = [NSColor colorWithCalibratedRed:0.0 green:0.5 blue:1.0 alpha:1.0];
	NSColor *rootColorRed = [NSColor colorWithCalibratedRed:1.0 green:1.0 blue:0.0 alpha:1.0];

   NSArray  *colorsBlue = [CattailArtNSColor RGBFlameArray:rootColorBlue 
      numberOfColorsInt:3
      hueStepDegreesCGFloat: 15.0
      saturationStepDegreesCGFloat: 0.0
      brightnessStepDegreesCGFloat:30.0 
      alignmentInt:-1];

   NSArray  *colorsRed = [CattailArtNSColor NewtonFlameArray:rootColorRed 
      numberOfColorsInt:3 
      hueStepDegreesCGFloat: 60.0
      saturationStepDegreesCGFloat: 0.0
      brightnessStepDegreesCGFloat:15.0 
      alignmentInt:1];
   
	NSMutableArray *colors = [[NSMutableArray alloc] init];
	[colors addObjectsFromArray:colorsBlue];
	[colors addObjectsFromArray:colorsRed];

	[gradientView setGradient:colors];

   [self updateColors];
}

-(id)init{
   [super init];
   hueShift = 15.0;
   valueShift = 15.0;
   saturationShift = 10.0;
   alignment = 1;
   return self;
}


-(IBAction)changeRootColor:(id)sender
{
	[self updateColors];
}

-(IBAction)changeColorWell:(id)sender
{
   [rootColorColorWell setColor:[sender color]];
   [self updateColors];
}

-(IBAction)changeConfiguration:(id)sender
{
   [self updateColors];
}

-(IBAction)showAboutPanel:(id)sender{
		BOOL successful  = [NSBundle loadNibNamed:@"About" owner:self];
   if(successful) NSLog(@"About box successful.");
}


@end
